/*
 * callbacks.cpp
 *
 *  Created on: Mar 21, 2012
 *      Author: dkaaser
 */

#include "nxwindow.h"
#include "gl.h"
namespace nx {

void nxWindow::key(int key, int x, int y) {
	switch (key) {
		case 'Q':
		case 'q':
		case 27: // escape key
			close();
			break;
		case 'F':
		case 'f':
			toggleFullscreen();
			break;
		case '+':
			zoom(windowWidth / 2, windowHeight / 2, 2.0);
			break;
		case '-':
			zoom(windowWidth / 2, windowHeight / 2, 0.5);
			break;
		default:
			nxLayer::key(key, x, y);
			break;
	}
	glutPostRedisplay();
}

void nxWindow::specialKey(int key, int x, int y) {
	const double scrollx = 0.125 * (left - right);
	const double scrolly = 0.125 * (top - bottom);
	switch (key) {
		case GLUT_KEY_LEFT:
			left += scrollx;
			right += scrollx;
			break;
		case GLUT_KEY_UP:
			top += scrolly;
			bottom += scrolly;
			break;
		case GLUT_KEY_RIGHT:
			left -= scrollx;
			right -= scrollx;
			break;
		case GLUT_KEY_DOWN:
			top -= scrolly;
			bottom -= scrolly;
			break;
	}
	updateDisplay();
}
void nxWindow::reshape(int x, int y) {
	windowWidth = x;
	windowHeight = y;
	updateDisplay();
}
void nxWindow::click(int button, int state, int x, int y) {
	clickX = x;
	clickY = y;
	if (button == 3 && state == 1)
		zoom(x, y, 2.0);
	else if (button == 4 && state == 1)
		zoom(x, y, 0.5);
}
void nxWindow::mouseDown(int x, int y) {
	double movex = ((double) (x - clickX) / (double) windowWidth) * (left - right);
	double movey = ((double) (y - clickY) / (double) windowHeight) * (top - bottom);
	left += movex;
	right += movex;
	top += movey;
	bottom += movey;
	updateDisplay();
	clickX = x;
	clickY = y;

}

void nxWindow::mouseMove(int x, int y) {
	mousePosition = unproject(x, windowHeight - y);
	glutPostRedisplay();
}
}
