/*
 * nxwindow.h
 *
 *  Created on: Mar 21, 2012
 *      Author: Dominik Kaaser
 */

#ifndef NXWINDOW_H_
#define NXWINDOW_H_

#include <string>
#include "nxlayer.h"
#include "nxvector.h"
namespace nx {

class nxWindow: public nxLayer {
public:
	nxWindow(const std::string& title, int* argc, char** argv);
	virtual ~nxWindow();

	void show();
	void close();

	static nxWindow* get() {
		return nxWindow::window;
	}
	const nxVector getMousePosition() const;
	const nxVector unproject(int x, int y) const;
	const double getPixelLength() const;
	const nxVector getOffset() const;
	void setZoomBounds(const double max, const double min);
	void setAntiAliasing(bool enable);
private:

	static nxWindow* window;

	static void __callback_draw();
	static void __callback_key(unsigned char, int, int);
	static void __callback_specialKey(int, int, int);
	static void __callback_reshape(int, int);
	static void __callback_click(int, int, int, int);
	static void __callback_mouseDown(int, int);
	static void __callback_mouseMove(int, int);

	nxVector mousePosition;

	int windowWidth;
	int windowHeight;
	int windowLeft;
	int windowTop;

	int restoreWidth;
	int restoreHeight;

	double top;
	double right;
	double bottom;
	double left;

	int id;

	bool fullscreen;

	int clickX;
	int clickY;

	double maxZoom;
	double minZoom;

	void key(int key, int x, int y);
	void specialKey(int key, int x, int y);
	void reshape(int x, int y);
	void click(int button, int state, int x, int y);
	void mouseDown(int x, int y);
	void mouseMove(int x, int y);

	void updateDisplay();

	void initDraw();

	void toggleFullscreen();

	void zoom(const int x, const int y, const double factor);

};



}
#endif /* NXWINDOW_H_ */
